@@ -33,7 +33,7 @@ fi
 
 create_tmpdir() {
 	mkdir $tmpdir
-	cp -r Makefile build_packages.sh zlibrary fbreader makefiles README.build distributions distributions-nonGPL $tmpdir
+	cp -r Makefile build_packages.sh zlibrary fbreader makefiles README.build CHANGES* distributions distributions-nonGPL ChangeLog $tmpdir
 	rm -rf `find $tmpdir -name ".svn"`
 	make -C $tmpdir distclean 1> /dev/null 2>&1
 
@@ -48,6 +48,9 @@ create_tmpdir() {
 		echo -en "Removing Swedish localization... ";
 		rm -rf fbreader/data/resources/sv.xml zlibrary/core/data/resources/sv.xml fbreader/data/help/MiniHelp.*.sv.fb2;
 		echo OK;
+		echo -en "Removing German localization... ";
+		rm -rf fbreader/data/resources/de.xml zlibrary/core/data/resources/de.xml fbreader/data/help/MiniHelp.*.de.fb2;
+		echo OK;
 		echo -en "Removing Czech hyphenation patterns... ";
 		zip -dq zlibrary/text/data/hyphenationPatterns.zip cs.pattern;
 		echo OK;
@@ -84,7 +87,7 @@ build_package() {
 					/scratchbox/login -d `pwd` $make_package ARCHITECTURE=$1 $2
 					;;
 				maemo5)
-					/scratchbox/login sb-conf se FREMANTLE_X86
+					/scratchbox/login sb-conf se FREMANTLE_ARMEL
 					/scratchbox/login -d `pwd` $make_package ARCHITECTURE=$1 $2
 					;;
 				*)
@@ -131,11 +134,7 @@ if [ $1 == all ]; then
 elif [ $1 == supported ]; then
 	create_tmpdir
 	build_package desktop debian
-	build_package maemo2 debian
-	build_package maemo3 debian
-	build_package maemo4 debian
 	build_package win32 nsi
-	build_package desktop tarball
 	build_package source tarball
 	remove_tmpdir
 else
