@@ -1,7 +1,7 @@
 #!/bin/sh
 
-if [ $# != 2 ]; then
-	echo -e "usage\n  $0 <platform> <install_dir>";
+if [ $# != 3 ]; then
+	echo -e "usage\n  $0 <platform> <ui_type> <install_dir>";
 	exit 0;
 fi;
 
@@ -10,8 +10,18 @@ case "$1" in
 		toolbar_file=data/default/toolbar.desktop.xml
 		fullscreen_toolbar_file=data/default/fullscreen_toolbar.desktop.xml
 		;;
+	macosx)
+		toolbar_file=data/default/toolbar.macosx.xml
+		;;
 	maemo)
-		toolbar_file=data/default/toolbar.maemo.xml
+		case "$2" in
+			maemo5)
+		    toolbar_file=data/default/toolbar.maemo5.xml
+				;;
+			*)
+		    toolbar_file=data/default/toolbar.maemo.xml
+				;;
+			esac;
 		;;
 	pepperpad3)
 		toolbar_file=data/default/toolbar.full.xml
@@ -25,9 +35,19 @@ case "$1" in
 esac;
 
 case "$1" in
-	maemo|zaurus_640x480|zaurus_240x320|pma400)
+	zaurus_640x480|zaurus_240x320|pma400)
 		menubar_file=data/default/menubar.xml
 		;;
+	maemo)
+		case "$2" in
+			maemo5)
+				menubar_file=data/default/menubar.maemo5.xml
+				;;
+			*)
+				menubar_file=data/default/menubar.xml
+				;;
+			esac;
+		;;
 	moto)
 		menubar_file=data/default/menubar.moto.xml
 		;;
@@ -36,13 +56,13 @@ case "$1" in
 esac;
 
 if [ "$toolbar_file" != "" ]; then
-	install -m 0644 $toolbar_file $2/toolbar.xml;
+	install -m 0644 $toolbar_file $3/toolbar.xml;
 fi;
 
 if [ "$fullscreen_toolbar_file" != "" ]; then
-	install -m 0644 $fullscreen_toolbar_file $2/fullscreen_toolbar.xml;
+	install -m 0644 $fullscreen_toolbar_file $3/fullscreen_toolbar.xml;
 fi;
 
 if [ "$menubar_file" != "" ]; then
-	install -m 0644 $menubar_file $2/menubar.xml;
+	install -m 0644 $menubar_file $3/menubar.xml;
 fi;
