@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,29 +24,37 @@
 #include "BookReader.h"
 
 #include "../formats/FormatPlugin.h"
+#include "../library/Book.h"
 
-BookModel::BookModel(const BookDescriptionPtr description) : myDescription(description) {
-	myBookTextModel = new ZLTextPlainModel(102400);
-	myContentsModel = new ContentsModel();
-	ZLFile file(description->fileName());
-	FormatPlugin *plugin = PluginCollection::instance().plugin(file, false);
-	if (plugin != 0) {
-		plugin->readModel(*description, *this);
+BookModel::BookModel(const shared_ptr<Book> book) : myBook(book) {
+	myBookTextModel = new ZLTextPlainModel(book->language(), 102400);
+	myContentsModel = new ContentsModel(book->language());
+	ZLFile file(book->filePath());
+	shared_ptr<FormatPlugin> plugin = PluginCollection::Instance().plugin(file, false);
+	if (!plugin.isNull()) {
+		plugin->readModel(*this);
 	}
 }
 
 BookModel::~BookModel() {
 }
 
-const std::string &BookModel::fileName() const {
-	return myDescription->fileName();
+void BookModel::setHyperlinkMatcher(shared_ptr<HyperlinkMatcher> matcher) {
+	myHyperlinkMatcher = matcher;
 }
-
+	
 BookModel::Label BookModel::label(const std::string &id) const {
+	if (!myHyperlinkMatcher.isNull()) {
+		return myHyperlinkMatcher->match(myInternalHyperlinks, id);
+	}
+
 	std::map<std::string,Label>::const_iterator it = myInternalHyperlinks.find(id);
 	return (it != myInternalHyperlinks.end()) ? it->second : Label(0, -1);
 }
 
+ContentsModel::ContentsModel(const std::string &language) : ZLTextTreeModel(language) {
+}
+
 void ContentsModel::setReference(const ZLTextTreeParagraph *paragraph, int reference) {
 	myReferenceByParagraph[paragraph] = reference;
 }
@@ -55,3 +63,7 @@ int ContentsModel::reference(const ZLTextTreeParagraph *paragraph) const {
 	std::map<const ZLTextTreeParagraph*,int>::const_iterator it = myReferenceByParagraph.find(paragraph);
 	return (it != myReferenceByParagraph.end()) ? it->second : -1;
 }
+
+const shared_ptr<Book> BookModel::book() const {
+	return myBook;
+}
