@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,5 +21,10 @@
 
 const std::string XMLNamespace::DublinCorePrefix = "http://purl.org/dc/elements";
 const std::string XMLNamespace::DublinCoreLegacyPrefix = "http://purl.org/metadata/dublin_core";
+const std::string XMLNamespace::DublinCoreTerms = "http://purl.org/dc/terms/";
 const std::string XMLNamespace::XLink = "http://www.w3.org/1999/xlink";
 const std::string XMLNamespace::OpenPackagingFormat = "http://www.idpf.org/2007/opf";
+const std::string XMLNamespace::Atom = "http://www.w3.org/2005/Atom";
+const std::string XMLNamespace::OpenSearch = "http://a9.com/-/spec/opensearch/1.1/";
+const std::string XMLNamespace::CalibreMetadata = "http://calibre.kovidgoyal.net/2009/metadata";
+const std::string XMLNamespace::Opds = "http://opds-spec.org/2010/catalog";
