@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,18 +22,18 @@
 
 #include "EncodingOptionEntry.h"
 
-static const std::string AUTO = "auto";
+#include "../library/Book.h"
 
-EncodingEntry::EncodingEntry(ZLStringOption &encodingOption) : myEncodingOption(encodingOption) {
-	const std::string &value = myEncodingOption.value();
-	if (value == AUTO) {
+AbstractEncodingEntry::AbstractEncodingEntry(const std::string &currentValue) {
+	const std::string &value = currentValue;
+	if (value == Book::AutoEncoding) {
 		myInitialSetName = value;
 		myInitialValues[value] = value;
 		setActive(false);
 		return;
 	}
 
-	const std::vector<shared_ptr<ZLEncodingSet> > &sets = ZLEncodingCollection::instance().sets();
+	const std::vector<shared_ptr<ZLEncodingSet> > &sets = ZLEncodingCollection::Instance().sets();
 	for (std::vector<shared_ptr<ZLEncodingSet> >::const_iterator it = sets.begin(); it != sets.end(); ++it) {
 		const std::vector<ZLEncodingConverterInfoPtr> &infos = (*it)->infos();
 		mySetNames.push_back((*it)->name());
@@ -53,11 +53,11 @@ EncodingEntry::EncodingEntry(ZLStringOption &encodingOption) : myEncodingOption(
 	}
 }
 
-const std::vector<std::string> &EncodingEntry::values() const {
-	if (initialValue() == AUTO) {
+const std::vector<std::string> &AbstractEncodingEntry::values() const {
+	if (initialValue() == Book::AutoEncoding) {
 		static std::vector<std::string> AUTO_ENCODING;
 		if (AUTO_ENCODING.empty()) {
-			AUTO_ENCODING.push_back(AUTO);
+			AUTO_ENCODING.push_back(Book::AutoEncoding);
 		}
 		return AUTO_ENCODING;
 	}
@@ -65,7 +65,7 @@ const std::vector<std::string> &EncodingEntry::values() const {
 	return it->second;
 }
 
-const std::string &EncodingEntry::initialValue() const {
+const std::string &AbstractEncodingEntry::initialValue() const {
 	if (myInitialValues[myInitialSetName].empty()) {
 		std::map<std::string,std::vector<std::string> >::const_iterator it = myValues.find(myInitialSetName);
 		myInitialValues[myInitialSetName] = it->second[0];
@@ -73,17 +73,33 @@ const std::string &EncodingEntry::initialValue() const {
 	return myInitialValues[myInitialSetName];
 }
 
-void EncodingEntry::onAccept(const std::string &value) {
-	if (initialValue() != AUTO) {
-		myEncodingOption.setValue(myValueByName[value]);
+void AbstractEncodingEntry::onAccept(const std::string &value) {
+	if (initialValue() != Book::AutoEncoding) {
+		onAcceptValue(myValueByName[value]);
 	}
 }
 
-void EncodingEntry::onValueSelected(int index) {
+void AbstractEncodingEntry::onValueSelected(int index) {
 	myInitialValues[myInitialSetName] = values()[index];
 }
 
-EncodingSetEntry::EncodingSetEntry(EncodingEntry &encodingEntry) : myEncodingEntry(encodingEntry) {
+
+
+
+
+EncodingEntry::EncodingEntry(ZLStringOption &encodingOption) : 
+	AbstractEncodingEntry(encodingOption.value()), 
+	myEncodingOption(encodingOption) {
+}
+
+void EncodingEntry::onAcceptValue(const std::string &value) {
+	myEncodingOption.setValue(value);
+}
+
+
+
+
+EncodingSetEntry::EncodingSetEntry(AbstractEncodingEntry &encodingEntry) : myEncodingEntry(encodingEntry) {
 }
 
 const std::string &EncodingSetEntry::initialValue() const {
