@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,51 +25,56 @@
 
 #include "../bookmodel/BookModel.h"
 
-ContentsView::ContentsView(FBReader &reader, shared_ptr<ZLPaintContext> context) : FBView(reader, context) {
+ContentsView::ContentsView(ZLPaintContext &context) : FBView(context) {
 }
 
 ContentsView::~ContentsView() {
 }
 
 bool ContentsView::_onStylusMove(int x, int y) {
-	int index = paragraphIndexByCoordinates(x, y);
-	if ((index < 0) || ((int)model()->paragraphsNumber() <= index)) {
-		fbreader().setHyperlinkCursor(false);
+	FBReader &fbreader = FBReader::Instance();
+
+	int index = textArea().paragraphIndexByCoordinates(x, y);
+	if ((index < 0) || ((int)textArea().model()->paragraphsNumber() <= index)) {
+		fbreader.setHyperlinkCursor(false);
 		return true;
 	}
 
-	const ContentsModel &contentsModel = (const ContentsModel&)*model();
+	const ContentsModel &contentsModel = (const ContentsModel&)*textArea().model();
 	const ZLTextTreeParagraph *paragraph = (const ZLTextTreeParagraph*)contentsModel[index];
 	
-	fbreader().setHyperlinkCursor(contentsModel.reference(paragraph) >= 0);
+	fbreader.setHyperlinkCursor(contentsModel.reference(paragraph) >= 0);
 	return true;
 }
 
 bool ContentsView::_onStylusPress(int x, int y) {
-	int index = paragraphIndexByCoordinates(x, y);
-	if ((index < 0) || ((int)model()->paragraphsNumber() <= index)) {
+	FBReader &fbreader = FBReader::Instance();
+
+	const ContentsModel &contentsModel = (const ContentsModel&)*textArea().model();
+	int index = textArea().paragraphIndexByCoordinates(x, y);
+	if ((index < 0) || ((int)contentsModel.paragraphsNumber() <= index)) {
 		return false;
 	}
 
-	const ContentsModel &contentsModel = (const ContentsModel&)*model();
 	const ZLTextTreeParagraph *paragraph = (const ZLTextTreeParagraph*)contentsModel[index];
 	
 	int reference = contentsModel.reference(paragraph);
 
 	if (reference >= 0) {
-		fbreader().bookTextView().gotoParagraph(reference);
-		fbreader().showBookTextView();
+		fbreader.bookTextView().gotoParagraph(reference);
+		fbreader.showBookTextView();
 	}
 
 	return true;
 }
 
 bool ContentsView::isEmpty() const {
-	return (model() == 0) || (model()->paragraphsNumber() == 0);
+	shared_ptr<ZLTextModel> model = textArea().model();
+	return model.isNull() || model->paragraphsNumber() == 0;
 }
 
 size_t ContentsView::currentTextViewParagraph(bool includeStart) const {
-	const ZLTextWordCursor &cursor = fbreader().bookTextView().startCursor();
+	const ZLTextWordCursor &cursor = FBReader::Instance().bookTextView().textArea().startCursor();
 	if (!cursor.isNull()) {
 		long reference = cursor.paragraphCursor().index();
 		bool startOfParagraph = cursor.elementIndex() == 0;
@@ -77,8 +82,9 @@ size_t ContentsView::currentTextViewParagraph(bool includeStart) const {
 			++reference;
 			startOfParagraph = true;
 		}
-		size_t length = model()->paragraphsNumber();
-		const ContentsModel &contentsModel = (const ContentsModel&)*model();
+		shared_ptr<ZLTextModel> model = textArea().model();
+		size_t length = model->paragraphsNumber();
+		const ContentsModel &contentsModel = (const ContentsModel&)*model;
 		for (size_t i = 1; i < length; ++i) {
 			long contentsReference =
 				contentsModel.reference(((const ZLTextTreeParagraph*)contentsModel[i]));
@@ -93,10 +99,10 @@ size_t ContentsView::currentTextViewParagraph(bool includeStart) const {
 }
 
 void ContentsView::gotoReference() {
-	model()->removeAllMarks();
+	textArea().model()->removeAllMarks();
 	const size_t selected = currentTextViewParagraph();
 	highlightParagraph(selected);
 	preparePaintInfo();
 	gotoParagraph(selected);
-	scrollPage(false, ZLTextView::SCROLL_PERCENTAGE, 40);
+	scrollPage(false, ZLTextAreaController::SCROLL_PERCENTAGE, 40);
 }
