@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 class ContentsView : public FBView {
 
 public:
-	ContentsView(FBReader &reader, shared_ptr<ZLPaintContext> context);
+	ContentsView(ZLPaintContext &context);
 	~ContentsView();
 
 	bool isEmpty() const;
