@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,22 +29,23 @@
 #include <ZLApplication.h>
 #include <ZLKeyBindings.h>
 
-#include "../collection/BookCollection.h"
-#include "../description/BookDescription.h"
+#include "../library/Library.h"
 #include "../external/ProgramCollection.h"
 
-class ZLViewWidget;
 class ZLMessageHandler;
 
+class Book;
 class BookModel;
 class BookTextView;
-class CollectionView;
 
 class FBReader : public ZLApplication {
 
+public:
+	static FBReader &Instance();
+
 public:
 	// returns true if description was found or error message was shown
-	static bool createDescription(const std::string &fileName, BookDescriptionPtr &description);
+	static bool createBook(const std::string &fileName, shared_ptr<Book> &book);
 
 	static const std::string PageIndexParameter;
 
@@ -55,31 +56,19 @@ public:
 		FOOTNOTE_MODE = 1 << 1,
 		CONTENTS_MODE = 1 << 2,
 		BOOKMARKS_MODE = 1 << 3,
-		BOOK_COLLECTION_MODE = 1 << 4,
-		NET_LIBRARY_MODE = 1 << 5,
-		ALL_MODES = 0x3F
-	};
-
-	struct ScrollingOptions {
-		ScrollingOptions(const std::string &groupName, long delayValue, long modeValue, long linesToKeepValue, long linesToScrollValue, long percentToScrollValue);
-		
-		ZLIntegerRangeOption DelayOption;
-		ZLIntegerOption ModeOption;
-		ZLIntegerRangeOption LinesToKeepOption;
-		ZLIntegerRangeOption LinesToScrollOption;
-		ZLIntegerRangeOption PercentToScrollOption;
+		LIBRARY_MODE = 1 << 4,
+		NETWORK_LIBRARY_MODE = 1 << 5,
+		ALL_MODES = 0xFF
 	};
 
 public:
 	ZLBooleanOption QuitOnCancelOption;
 
-	ScrollingOptions LargeScrollingOptions;
-	ScrollingOptions SmallScrollingOptions;
-	ScrollingOptions MouseScrollingOptions;
-	ScrollingOptions TapScrollingOptions;
+	ZLIntegerRangeOption KeyScrollingDelayOption;
+	ZLIntegerRangeOption LinesToScrollOption;
+	ZLIntegerRangeOption LinesToKeepOption;
 	ZLBooleanOption EnableTapScrollingOption;
 	ZLBooleanOption TapScrollingOnFingerOnlyOption;
-	ZLBooleanOption TapScrollingOnDragOnlyOption;
 
 	ZLBooleanOption UseSeparateBindingsOption;
 
@@ -92,21 +81,28 @@ public:
 	void setMode(ViewMode mode);
 	ViewMode mode() const;
 
+	shared_ptr<Book> currentBook() const;
+
+	void refreshWindow();
+
 private:
 	void initWindow();
 
-	bool runBookInfoDialog(const std::string &fileName);
-
 	void clearTextCaches();
 
 	void restorePreviousMode();
 
 	bool closeView();
 	std::string helpFileName(const std::string &language) const;
-	void openFile(const std::string &fileName);
+
+	void openFile(const std::string &filePath);
+	bool canDragFiles(const std::vector<std::string> &filePaths) const;
+	void dragFiles(const std::vector<std::string> &filePaths);
 
 	bool isViewFinal() const;
 
+	void showLibraryView();
+
 public:
 	shared_ptr<ZLKeyBindings> keyBindings();
 	shared_ptr<ZLKeyBindings> keyBindings(ZLView::Angle angle);
@@ -115,20 +111,20 @@ public:
 	void openInDictionary(const std::string &word);
 
 	shared_ptr<ProgramCollection> webBrowserCollection() const;
+	void openLinkInBrowser(const std::string &url) const;
 
 	void tryShowFootnoteView(const std::string &id, const std::string &type);
 	BookTextView &bookTextView() const;
-	CollectionView &collectionView() const;
 	void showBookTextView();
-	void openBook(BookDescriptionPtr description);
+	void openBook(shared_ptr<Book> book);
 
-	RecentBooks &recentBooks();
-	const RecentBooks &recentBooks() const;
+	void invalidateNetworkView();
+	void invalidateAccountDependents();
 
 private:
 	shared_ptr<ProgramCollection> dictionaryCollection() const;
 
-	void openBookInternal(BookDescriptionPtr description);
+	void openBookInternal(shared_ptr<Book> book);
 	friend class OpenBookRunnable;
 	void rebuildCollectionInternal();
 	friend class RebuildCollectionRunnable;
@@ -138,16 +134,17 @@ private:
 	ViewMode myMode;
 	ViewMode myPreviousMode;
 
-	shared_ptr<ZLView> myFootnoteView;	
-	shared_ptr<ZLView> myBookTextView;	
-	shared_ptr<ZLView> myContentsView;	
-	shared_ptr<ZLView> myCollectionView;	
-	shared_ptr<ZLView> myNetLibraryView;	
-	shared_ptr<ZLPopupData> myRecentBooksPopupData;	
+	shared_ptr<ZLView> myFootnoteView;
+	shared_ptr<ZLView> myBookTextView;
+	shared_ptr<ZLView> myContentsView;
+	shared_ptr<ZLView> myNetworkLibraryView;
+	shared_ptr<ZLView> myLibraryByAuthorView;
+	shared_ptr<ZLView> myLibraryByTagView;
+	shared_ptr<ZLPopupData> myRecentBooksPopupData;
 
 	ZLTime myLastScrollingTime;
 
-	BookModel *myModel;
+	shared_ptr<BookModel> myModel;
 
 	shared_ptr<ZLKeyBindings> myBindings0;
 	shared_ptr<ZLKeyBindings> myBindings90;
@@ -161,8 +158,6 @@ private:
 
 	shared_ptr<ZLMessageHandler> myOpenFileHandler;
 
-	RecentBooks myRecentBooks;
-
 	enum {
 		RETURN_TO_TEXT_MODE,
 		UNFULLSCREEN
@@ -172,7 +167,6 @@ friend class OpenFileHandler;
 
 friend class OptionsDialog;
 friend class FBView;
-friend class NetLibraryView;
 
 //friend class ShowCollectionAction;
 friend class ShowHelpAction;
@@ -190,6 +184,7 @@ friend class SearchPatternAction;
 friend class FindNextAction;
 friend class FindPreviousAction;
 friend class ScrollingAction;
+friend class ScrollingAction2;
 friend class ChangeFontSizeAction;
 friend class CancelAction;
 //friend class ToggleIndicatorAction;
@@ -202,6 +197,8 @@ friend class SelectionAction;
 friend class SearchOnNetworkAction;
 friend class AdvancedSearchOnNetworkAction;
 friend class FBFullscreenAction;
+friend class BooksOrderAction;
+friend class LogOutAction;
 };
 
 #endif /* __FBREADER_H__ */
