@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,19 +20,21 @@
 #include "FBReaderActions.h"
 
 const std::string ActionCode::SHOW_READING = "showReading";
-const std::string ActionCode::SHOW_COLLECTION = "showLibrary";
-const std::string ActionCode::SHOW_NET_LIBRARY = "showNetLibrary";
-const std::string ActionCode::SHOW_OPTIONS = "preferences";
+const std::string ActionCode::SHOW_LIBRARY = "showLibrary";
+const std::string ActionCode::SHOW_NETWORK_LIBRARY = "showNetLibrary";
+const std::string ActionCode::SHOW_TOC = "toc";
+const std::string ActionCode::SHOW_HELP = "showHelp";
+const std::string ActionCode::SHOW_BOOK_INFO_DIALOG = "bookInfo";
+const std::string ActionCode::SHOW_OPTIONS_DIALOG = "preferences";
 const std::string ActionCode::UNDO = "undo";
 const std::string ActionCode::REDO = "redo";
-const std::string ActionCode::SHOW_CONTENTS = "toc";
 const std::string ActionCode::SEARCH = "search";
 const std::string ActionCode::FIND_PREVIOUS = "findPrevious";
 const std::string ActionCode::FIND_NEXT = "findNext";
-const std::string ActionCode::LARGE_SCROLL_FORWARD = "largeScrollForward";
-const std::string ActionCode::LARGE_SCROLL_BACKWARD = "largeScrollBackward";
-const std::string ActionCode::SMALL_SCROLL_FORWARD = "smallScrollForward";
-const std::string ActionCode::SMALL_SCROLL_BACKWARD = "smallScrollBackward";
+const std::string ActionCode::PAGE_SCROLL_FORWARD = "pageForward";
+const std::string ActionCode::PAGE_SCROLL_BACKWARD = "pageBackward";
+const std::string ActionCode::LINE_SCROLL_FORWARD = "lineForward";
+const std::string ActionCode::LINE_SCROLL_BACKWARD = "lineBackward";
 const std::string ActionCode::MOUSE_SCROLL_FORWARD = "mouseScrollForward";
 const std::string ActionCode::MOUSE_SCROLL_BACKWARD = "mouseScrollBackward";
 const std::string ActionCode::TAP_SCROLL_FORWARD = "tapScrollForward";
@@ -47,10 +49,9 @@ const std::string ActionCode::SHOW_HIDE_POSITION_INDICATOR = "toggleIndicator";
 const std::string ActionCode::TOGGLE_FULLSCREEN = "toggleFullscreen";
 const std::string ActionCode::FULLSCREEN_ON = "onFullscreen";
 const std::string ActionCode::ADD_BOOK = "addBook";
-const std::string ActionCode::SHOW_BOOK_INFO = "bookInfo";
-const std::string ActionCode::SHOW_HELP = "showHelp";
 const std::string ActionCode::ROTATE_SCREEN = "rotate";
 const std::string ActionCode::QUIT = "quit";
+const std::string ActionCode::FORCE_QUIT = "forceQuit";
 const std::string ActionCode::OPEN_PREVIOUS_BOOK = "previousBook";
 const std::string ActionCode::GOTO_NEXT_TOC_SECTION = "nextTOCSection";
 const std::string ActionCode::GOTO_PREVIOUS_TOC_SECTION = "previousTOCSection";
@@ -63,3 +64,4 @@ const std::string ActionCode::SEARCH_ON_NETWORK = "searchOnNetwork";
 const std::string ActionCode::ADVANCED_SEARCH_ON_NETWORK = "advancedSearchOnNetwork";
 const std::string ActionCode::ORGANIZE_BOOKS_BY_AUTHOR = "byAuthor";
 const std::string ActionCode::ORGANIZE_BOOKS_BY_TAG = "byTag";
+const std::string ActionCode::FILTER_LIBRARY = "filterLibrary";
