@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,21 +18,17 @@
  */
 
 #include <cmath>
+#include <algorithm>
 
 #include <ZLUnicodeUtil.h>
+#include <ZLTimeManager.h>
+#include <ZLTextSelectionModel.h>
 
 #include "FBView.h"
 #include "FBReader.h"
 #include "FBReaderActions.h"
-
-static const std::string OPTIONS = "Options";
-
-FBMargins::FBMargins() :
-	LeftMarginOption(ZLCategoryKey::LOOK_AND_FEEL, OPTIONS, "LeftMargin", 0, 1000, 4),
-	RightMarginOption(ZLCategoryKey::LOOK_AND_FEEL, OPTIONS, "RightMargin", 0, 1000, 4),
-	TopMarginOption(ZLCategoryKey::LOOK_AND_FEEL, OPTIONS, "TopMargin", 0, 1000, 0),
-	BottomMarginOption(ZLCategoryKey::LOOK_AND_FEEL, OPTIONS, "BottomMargin", 0, 1000, 4) {
-}
+#include "../options/FBOptions.h"
+#include "../options/FBTextStyle.h"
 
 static const std::string INDICATOR = "Indicator";
 
@@ -80,7 +76,6 @@ int FBIndicatorStyle::fontSize() const {
 }
 
 shared_ptr<ZLTextPositionIndicatorInfo> FBView::ourIndicatorInfo;
-shared_ptr<FBMargins> FBView::ourMargins;
 shared_ptr<ZLBooleanOption> FBView::ourSelectionOption;
 
 FBIndicatorStyle& FBView::commonIndicatorInfo() {
@@ -90,7 +85,7 @@ FBIndicatorStyle& FBView::commonIndicatorInfo() {
 	return (FBIndicatorStyle&)*ourIndicatorInfo;
 }
 
-FBView::FBView(FBReader &reader, shared_ptr<ZLPaintContext> context) : ZLTextView(reader, context) {
+FBView::FBView(ZLPaintContext &context) : ZLTextView(context) {
 }
 
 shared_ptr<ZLTextPositionIndicatorInfo> FBView::indicatorInfo() const {
@@ -102,9 +97,9 @@ shared_ptr<ZLTextPositionIndicatorInfo> FBView::indicatorInfo() const {
 
 void FBView::doTapScrolling(int y) {
 	if (2 * y < context().height()) {
-		fbreader().doAction(ActionCode::TAP_SCROLL_BACKWARD);
+		FBReader::Instance().doAction(ActionCode::TAP_SCROLL_BACKWARD);
 	} else {
-		fbreader().doAction(ActionCode::TAP_SCROLL_FORWARD);
+		FBReader::Instance().doAction(ActionCode::TAP_SCROLL_FORWARD);
 	}
 }
 
@@ -119,17 +114,27 @@ const std::string &FBView::caption() const {
 
 void FBView::setCaption(const std::string &caption) {
 	myCaption = caption;
+	std::replace(myCaption.begin(), myCaption.end(), '\n', ' ');
+	std::replace(myCaption.begin(), myCaption.end(), '\r', ' ');
+	ZLUnicodeUtil::cleanUtf8String(myCaption);
 }
 
 bool FBView::onStylusPress(int x, int y) {
+	if (!myTapScroller.isNull()) {
+		ZLTimeManager::Instance().removeTask(myTapScroller);
+		myTapScroller.reset();
+	}
+
 	myPressedX = x;
 	myPressedY = y;
-	myIsReleasedWithoutMotion = true;
+	myIsReleasedWithoutMotion = false;
 
 	if (ZLTextView::onStylusPress(x, y)) {
 		return true;
 	}
 
+	myIsReleasedWithoutMotion = true;
+	
 	if (_onStylusPress(x, y)) {
 		return true;
 	}
@@ -141,33 +146,51 @@ bool FBView::_onStylusPress(int, int) {
 	return false;
 }
 
+class FBView::TapScroller : public ZLRunnable {
+
+public:
+	TapScroller(FBView &view, int y);
+
+private:
+	void run();
+
+private:
+	FBView &myView;
+	const int myY;
+};
+
+FBView::TapScroller::TapScroller(FBView &view, int y) : myView(view), myY(y) {
+}
+
+void FBView::TapScroller::run() {
+	myView.doTapScrolling(myY);
+}
+
 bool FBView::onStylusRelease(int x, int y) {
+	const bool hadSelection = !selectionModel().isEmpty();
+
+	if (!myTapScroller.isNull()) {
+		ZLTimeManager::Instance().removeTask(myTapScroller);
+		myTapScroller.reset();
+	}
+
 	if (ZLTextView::onStylusRelease(x, y)) {
 		return true;
 	}
-
+	
 	if (_onStylusRelease(x, y)) {
 		return true;
 	}
 
+	FBReader &fbreader = FBReader::Instance();
 	myIsReleasedWithoutMotion =
 		myIsReleasedWithoutMotion && (abs(x - pressedX()) <= 5) && (abs(y - pressedY()) <= 5);
-
-	// Do scrolling by tapping
-	if (isReleasedWithoutMotion() &&
-			fbreader().EnableTapScrollingOption.value() &&
-			!fbreader().TapScrollingOnDragOnlyOption.value() &&
+	if (!hadSelection && isReleasedWithoutMotion() &&
+			fbreader.EnableTapScrollingOption.value() &&
 			(!ZLBooleanOption(ZLCategoryKey::EMPTY, ZLOption::PLATFORM_GROUP, ZLOption::FINGER_TAP_DETECTABLE, false).value() ||
-			 !fbreader().TapScrollingOnFingerOnlyOption.value())) {
-		doTapScrolling(y);
-		return true;
-	}
-
-	// Do scrolling by dragging
-	int dx = x!=pressedX()? abs(x - pressedX()) : 1;
-	int dy = abs(y - pressedY());
-	if((dy / dx >= 5) && fbreader().TapScrollingOnDragOnlyOption.value()) {
-		doTapScrolling(y>pressedY()? 0:context().height());
+			 !fbreader.TapScrollingOnFingerOnlyOption.value())) {
+		myTapScroller = new TapScroller(*this, y);
+		ZLTimeManager::Instance().addAutoRemovableTask(myTapScroller, doubleClickDelay());
 		return true;
 	}
 
@@ -182,7 +205,7 @@ bool FBView::onStylusMove(int x, int y) {
 	if (ZLTextView::onStylusMove(x, y)) {
 		return true;
 	}
-
+	
 	if (_onStylusMove(x, y)) {
 		return true;
 	}
@@ -205,7 +228,7 @@ bool FBView::onStylusMovePressed(int x, int y) {
 	if (ZLTextView::onStylusMovePressed(x, y)) {
 		return true;
 	}
-
+	
 	if (_onStylusMovePressed(x, y)) {
 		return true;
 	}
@@ -217,13 +240,13 @@ bool FBView::_onStylusMovePressed(int, int) {
 	return false;
 }
 
-std::string FBView::word(const ZLTextElementArea &area) const {
+std::string FBView::word(const ZLTextElementRectangle &rectangle) const {
 	std::string txt;
 
-	if (area.Kind == ZLTextElement::WORD_ELEMENT) {
-		ZLTextWordCursor cursor = startCursor();
-		cursor.moveToParagraph(area.ParagraphIndex);
-		cursor.moveTo(area.ElementIndex, 0);
+	if (rectangle.Kind == ZLTextElement::WORD_ELEMENT) {
+		ZLTextWordCursor cursor = textArea().startCursor();
+		cursor.moveToParagraph(rectangle.ParagraphIndex);
+		cursor.moveTo(rectangle.ElementIndex, 0);
 		const ZLTextWord &word = (ZLTextWord&)cursor.element();
 		ZLUnicodeUtil::Ucs4String ucs4;
 		ZLUnicodeUtil::utf8ToUcs4(ucs4, word.Data, word.Size);
@@ -238,7 +261,7 @@ std::string FBView::word(const ZLTextElementArea &area) const {
 				--it;
 			}
 			ucs4.erase(it + 1, ucs4.end());
-
+    
 			ZLUnicodeUtil::ucs4ToUtf8(txt, ucs4);
 		}
 	}
@@ -246,24 +269,36 @@ std::string FBView::word(const ZLTextElementArea &area) const {
 }
 
 int FBView::leftMargin() const {
-	return margins().LeftMarginOption.value();
+	return FBOptions::Instance().LeftMarginOption.value();
 }
 
 int FBView::rightMargin() const {
-	return margins().RightMarginOption.value();
+	return FBOptions::Instance().RightMarginOption.value();
 }
 
 int FBView::topMargin() const {
-	return margins().TopMarginOption.value();
+	return FBOptions::Instance().TopMarginOption.value();
 }
 
 int FBView::bottomMargin() const {
-	return margins().BottomMarginOption.value();
+	return FBOptions::Instance().BottomMarginOption.value();
+}
+
+ZLColor FBView::backgroundColor() const {
+	return FBOptions::Instance().BackgroundColorOption.value();
+}
+
+ZLColor FBView::color(const std::string &colorStyle) const {
+	return FBOptions::Instance().colorOption(colorStyle).value();
+}
+
+shared_ptr<ZLTextStyle> FBView::baseStyle() const {
+	return FBTextStyle::InstanceAsPtr();
 }
 
 ZLBooleanOption &FBView::selectionOption() {
 	if (ourSelectionOption.isNull()) {
-		ourSelectionOption = new ZLBooleanOption(ZLCategoryKey::LOOK_AND_FEEL, OPTIONS, "IsSelectionEnabled", true);
+		ourSelectionOption = new ZLBooleanOption(ZLCategoryKey::LOOK_AND_FEEL, "Options", "IsSelectionEnabled", true);
 	}
 	return *ourSelectionOption;
 }
@@ -272,10 +307,8 @@ bool FBView::isSelectionEnabled() const {
 	return selectionOption().value();
 }
 
-void FBView::scrollAndUpdatePage(bool forward, ScrollingMode mode, unsigned int value) {
-	scrollPage(forward, mode, value);
-	preparePaintInfo();
-	fbreader().refreshWindow();
+int FBView::doubleClickDelay() const {
+	return isSelectionEnabled() ? 200 : 0;
 }
 
 bool FBView::hasContents() const {
