@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,23 +22,7 @@
 
 #include <ZLTextView.h>
 #include <ZLTextStyle.h>
-
-class FBReader;
-
-class FBMargins {
-
-public:
-	ZLIntegerRangeOption LeftMarginOption;
-	ZLIntegerRangeOption RightMarginOption;
-	ZLIntegerRangeOption TopMarginOption;
-	ZLIntegerRangeOption BottomMarginOption;
-
-	FBMargins();
-
-private:
-	FBMargins(const FBMargins&);
-	const FBMargins& operator = (const FBMargins&);
-};
+#include <ZLRunnable.h>
 
 class FBIndicatorStyle : public ZLTextPositionIndicatorInfo {
 
@@ -67,42 +51,44 @@ public:
 
 class FBView : public ZLTextView {
 
+private:
+	class TapScroller;
+
 public:
-	static FBMargins& margins();
 	static FBIndicatorStyle& commonIndicatorInfo();
 	static ZLBooleanOption &selectionOption();
 
-	void scrollAndUpdatePage(bool forward, ScrollingMode mode, unsigned int value);
-
 	virtual bool hasContents() const;
 
 private:
 	static shared_ptr<ZLTextPositionIndicatorInfo> ourIndicatorInfo;
-	static shared_ptr<FBMargins> ourMargins;
 	static shared_ptr<ZLBooleanOption> ourSelectionOption;
 
 protected:
 	void doTapScrolling(int y);
 
 public:
-	FBView(FBReader &reader, shared_ptr<ZLPaintContext> context);
+	FBView(ZLPaintContext &context);
 
+	void setCaption(const std::string &caption);
+
+private:
 	bool onFingerTap(int x, int y);
 
 	const std::string &caption() const;
-	void setCaption(const std::string &caption);
 
 	int leftMargin() const;
 	int rightMargin() const;
 	int topMargin() const;
 	int bottomMargin() const;
+	ZLColor backgroundColor() const;
+	ZLColor color(const std::string &colorStyle) const;
+	shared_ptr<ZLTextStyle> baseStyle() const;
 
 	bool isSelectionEnabled() const;
+	int doubleClickDelay() const;
 
 protected:
-	FBReader &fbreader();
-	const FBReader &fbreader() const;
-
 	bool onStylusPress(int x, int y);
 	virtual bool _onStylusPress(int x, int y);
 	bool onStylusRelease(int x, int y);
@@ -116,7 +102,7 @@ protected:
 	int pressedY() const;
 	bool isReleasedWithoutMotion() const;
 
-	std::string word(const ZLTextElementArea &area) const;
+	std::string word(const ZLTextElementRectangle &rectangle) const;
 
 	shared_ptr<ZLTextPositionIndicatorInfo> indicatorInfo() const;
 
@@ -126,18 +112,10 @@ private:
 	int myPressedX;
 	int myPressedY;
 	bool myIsReleasedWithoutMotion;
+
+	shared_ptr<ZLRunnable> myTapScroller;
 };
 
-inline FBReader &FBView::fbreader() { return (FBReader&)application(); }
-inline const FBReader &FBView::fbreader() const { return (const FBReader&)application(); }
-
-inline FBMargins& FBView::margins() {
-	if (ourMargins.isNull()) {
-		ourMargins = new FBMargins();
-	}
-	return *ourMargins;
-}
-
 inline int FBView::pressedX() const { return myPressedX; }
 inline int FBView::pressedY() const { return myPressedY; }
 inline bool FBView::isReleasedWithoutMotion() const { return myIsReleasedWithoutMotion; }
