@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include "FBReader.h"
 #include "FBView.h"
 #include "FBReaderActions.h"
-#include "../options/FBOptions.h"
+#include "../options/FBCategoryKey.h"
 
 #include <set>
 
@@ -57,7 +57,6 @@ const std::string &SearchPatternEntry::initialValue() const {
 
 const std::vector<std::string> &SearchPatternEntry::values() const {
 	if (myValues.empty()) {
-		// TODO: implement
 		myValues.push_back(myAction.SearchPatternOption.value());
 		for (int i = 1; i < 6; ++i) {
 			std::string pattern = PATTERN;
@@ -87,15 +86,15 @@ void SearchPatternEntry::onAccept(const std::string &value) {
 	}
 }
 
-SearchAction::SearchAction(FBReader &fbreader) : FBAction(fbreader) {
-}
-
 bool SearchAction::isVisible() const {
-	shared_ptr<ZLView> view = fbreader().currentView();
-	return !view.isNull() && ((FBView&)*view).hasContents();
+	shared_ptr<ZLView> view = FBReader::Instance().currentView();
+	return
+		!view.isNull() && 
+		view->isInstanceOf(ZLTextView::TYPE_ID) &&
+		((FBView&)*view).hasContents();
 }
 
-SearchPatternAction::SearchPatternAction(FBReader &fbreader) : SearchAction(fbreader),
+SearchPatternAction::SearchPatternAction() :
 	SearchBackwardOption(FBCategoryKey::SEARCH, SEARCH, "Backward", false),
 	SearchIgnoreCaseOption(FBCategoryKey::SEARCH, SEARCH, "IgnoreCase", true),
 	SearchInWholeTextOption(FBCategoryKey::SEARCH, SEARCH, "WholeText", false),
@@ -104,9 +103,9 @@ SearchPatternAction::SearchPatternAction(FBReader &fbreader) : SearchAction(fbre
 }
 
 void SearchPatternAction::run() {
-	ZLTextView &textView = (ZLTextView&)*fbreader().currentView();
+	ZLTextView &textView = (ZLTextView&)*FBReader::Instance().currentView();
 
-	shared_ptr<ZLDialog> searchDialog = ZLDialogManager::instance().createDialog(ZLResourceKey("textSearchDialog"));
+	shared_ptr<ZLDialog> searchDialog = ZLDialogManager::Instance().createDialog(ZLResourceKey("textSearchDialog"));
 
 	searchDialog->addOption(ZLResourceKey("text"), new SearchPatternEntry(*this));
 	searchDialog->addOption(ZLResourceKey("ignoreCase"), SearchIgnoreCaseOption);
@@ -130,26 +129,27 @@ void SearchPatternAction::run() {
 	}
 }
 
-FindNextAction::FindNextAction(FBReader &fbreader) : SearchAction(fbreader) {
-}
-
 bool FindNextAction::isEnabled() const {
-	shared_ptr<ZLView> view = fbreader().currentView();
-	return (!view.isNull()) && ((ZLTextView&)*view).canFindNext();
+	shared_ptr<ZLView> view = FBReader::Instance().currentView();
+	return
+		!view.isNull() && 
+		view->isInstanceOf(ZLTextView::TYPE_ID) &&
+		((ZLTextView&)*view).canFindNext();
+	return false;
 }
 
 void FindNextAction::run() {
-	((ZLTextView&)*fbreader().currentView()).findNext();
-}
-
-FindPreviousAction::FindPreviousAction(FBReader &fbreader) : SearchAction(fbreader) {
+	((ZLTextView&)*FBReader::Instance().currentView()).findNext();
 }
 
 bool FindPreviousAction::isEnabled() const {
-	shared_ptr<ZLView> view = fbreader().currentView();
-	return (!view.isNull()) && ((ZLTextView&)*view).canFindPrevious();
+	shared_ptr<ZLView> view = FBReader::Instance().currentView();
+	return
+		!view.isNull() && 
+		view->isInstanceOf(ZLTextView::TYPE_ID) &&
+		((ZLTextView&)*view).canFindPrevious();
 }
 
 void FindPreviousAction::run() {
-	((ZLTextView&)*fbreader().currentView()).findPrevious();
+	((ZLTextView&)*FBReader::Instance().currentView()).findPrevious();
 }
