@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +18,14 @@
  */
 
 #include <ZLTime.h>
+#include <ZLApplication.h>
 
 #include <ZLTextStyle.h>
 
 #include "FBView.h"
 #include "TimeUpdater.h"
 
-TimeUpdater::TimeUpdater(ZLApplication &application) : myApplication(application), myTime(-1) {
+TimeUpdater::TimeUpdater() : myTime(-1) {
 }
 
 void TimeUpdater::run() {
@@ -33,7 +34,7 @@ void TimeUpdater::run() {
 		short minutes = time.hours() * 60 + time.minutes();
 		if (myTime != minutes) {
 			myTime = minutes;
-			myApplication.refreshWindow();
+			ZLApplication::Instance().refreshWindow();
 		}
 	}
 }
