@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,18 +21,16 @@
 #define __TIMEUPDATER_H__
 
 #include <ZLRunnable.h>
-#include <ZLApplication.h>
 
 class TimeUpdater : public ZLRunnable {
 
 public:
-	TimeUpdater(ZLApplication &application);
+	TimeUpdater();
 
 private:
 	void run();
 
 private:
-	ZLApplication &myApplication;
 	short myTime;
 };
 
