@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * 02110-1301, USA.
  */
 
-#include <string.h>
+#include <cstring>
 
 #include "BitStream.h"
 
@@ -35,7 +35,7 @@ unsigned int BitStream::get4BytesDirect() {
 }
 
 bool BitStream::getBytesDirect(unsigned char *buffer, unsigned int length) {
-	if (myByteStream + 4 > myByteStreamEnd) {
+	if (myByteStream + length > myByteStreamEnd) {
 		return false;
 	}
 	memcpy(buffer, myByteStream, length);
