@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * 02110-1301, USA.
  */
 
-#include <string.h>
+#include <cstring>
 
 #include <ZLFile.h>
 #include <ZLStringUtil.h>
@@ -282,7 +282,7 @@ bool CHMFileInfo::init(ZLInputStream &stream) {
 						name = ZLUnicodeUtil::toLower(name);
 					}
 					myRecords.insert(
-						std::pair<std::string,CHMFileInfo::RecordInfo>(
+						std::make_pair(
 							name,
 							CHMFileInfo::RecordInfo(contentSection, offset, length)
 						)
