@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,22 +18,26 @@
  */
 
 #include <ZLInputStream.h>
+#include <ZLStringUtil.h>
 
 #include "DocBookDescriptionReader.h"
 
-DocBookDescriptionReader::DocBookDescriptionReader(BookDescription &description) : myDescription(description) {
+#include "../../library/Book.h"
+#include "../../library/Author.h"
+
+DocBookDescriptionReader::DocBookDescriptionReader(Book &book) : myBook(book) {
 	myReadTitle = false;
 	myReadAuthor = false;
 	for (int i = 0; i < 3; ++i) {
 		myReadAuthorName[i] = false;
 	}
-	myDescription.language() = "en";
+	myBook.setLanguage("en");
 	myDepth = 0;
 }
 
 void DocBookDescriptionReader::characterDataHandler(const char *text, size_t len) {
 	if (myReadTitle) {
-		myDescription.title().append(text, len);
+		myBook.setTitle(myBook.title() + std::string(text, len));
 	} else {
 		for (int i = 0; i < 3; ++i) {
 			if (myReadAuthorName[i]) {
@@ -87,8 +91,24 @@ void DocBookDescriptionReader::endElementHandler(int tag) {
 		case _TITLE:
 			myReadTitle = false;
 			break;
-		case _AUTHOR:
-			myDescription.addAuthor(myAuthorNames[0], myAuthorNames[1], myAuthorNames[2]);
+		case _AUTHOR: {
+				ZLStringUtil::stripWhiteSpaces(myAuthorNames[0]);
+				ZLStringUtil::stripWhiteSpaces(myAuthorNames[1]);
+				ZLStringUtil::stripWhiteSpaces(myAuthorNames[2]);
+				std::string fullName = myAuthorNames[0];
+				if (!fullName.empty() && !myAuthorNames[1].empty()) {
+					fullName += ' ';
+				}
+				fullName += myAuthorNames[1];
+				if (!fullName.empty() && !myAuthorNames[2].empty()) {
+					fullName += ' ';
+				}
+				fullName += myAuthorNames[2];
+				shared_ptr<Author> author = Author::create(fullName, myAuthorNames[2]);
+				if (!author.isNull()) {
+					myBook.authors().add( author );
+				}
+			}
 			myAuthorNames[0].erase();
 			myAuthorNames[1].erase();
 			myAuthorNames[2].erase();
@@ -108,6 +128,10 @@ void DocBookDescriptionReader::endElementHandler(int tag) {
 	}
 }
 
-bool DocBookDescriptionReader::readDescription(shared_ptr<ZLInputStream> stream) {
-	return readDocument(stream);
+bool DocBookDescriptionReader::readMetaInfo(shared_ptr<ZLInputStream> stream) {
+	bool code = readDocument(stream);
+	if (myBook.authors().empty()) {
+		myBook.authors().push_back( new Author() );
+	}
+	return code;
 }
