@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,13 +29,10 @@ public:
 	~DummyPlugin();
 	bool providesMetaInfo() const;
 	bool acceptsFile(const ZLFile &file) const;
-	bool readDescription(const std::string &path, BookDescription &description) const;
-	bool readModel(const BookDescription &description, BookModel &model) const;
+	bool readMetaInfo(Book &book) const;
+	bool readModel(BookModel &model) const;
 	const std::string &iconName() const;
+	shared_ptr<ZLImage> coverImage(const Book &book) const;
 };
 
-inline DummyPlugin::DummyPlugin() {}
-inline DummyPlugin::~DummyPlugin() {}
-inline bool DummyPlugin::providesMetaInfo() const { return true; }
-
 #endif /* __DUMMYPLUGIN_H__ */
