@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,16 +18,19 @@
  */
 
 #include <ZLFile.h>
+#include <ZLImage.h>
 #include <ZLStringUtil.h>
 #include <ZLDir.h>
 #include <ZLInputStream.h>
+#include <ZLLogger.h>
 
 #include "OEBPlugin.h"
-#include "OEBDescriptionReader.h"
+#include "OEBMetaInfoReader.h"
 #include "OEBBookReader.h"
+#include "OEBCoverReader.h"
 #include "OEBTextStream.h"
-#include "../../description/BookDescription.h"
 #include "../../bookmodel/BookModel.h"
+#include "../../library/Book.h"
 
 static const std::string OPF = "opf";
 static const std::string OEBZIP = "oebzip";
@@ -51,28 +54,33 @@ std::string OEBPlugin::opfFileName(const std::string &oebFileName) {
 		return oebFileName;
 	}
 
+	ZLLogger::Instance().println("epub", "Looking for opf file in " + oebFileName);
 	oebFile.forceArchiveType(ZLFile::ZIP);
 	shared_ptr<ZLDir> zipDir = oebFile.directory(false);
 	if (zipDir.isNull()) {
-		return "";
+		ZLLogger::Instance().println("epub", "Couldn't open zip archive");
+		return std::string();
 	}
 	std::vector<std::string> fileNames;
 	zipDir->collectFiles(fileNames, false);
 	for (std::vector<std::string>::const_iterator it = fileNames.begin(); it != fileNames.end(); ++it) {
+		ZLLogger::Instance().println("epub", "Item: " + *it);
 		if (ZLStringUtil::stringEndsWith(*it, ".opf")) {
 			return zipDir->itemPath(*it);
 		}
 	}
-	return "";
+	ZLLogger::Instance().println("epub", "Opf file not found");
+	return std::string();
 }
 
-bool OEBPlugin::readDescription(const std::string &path, BookDescription &description) const {
+bool OEBPlugin::readMetaInfo(Book &book) const {
+	const std::string &path = book.filePath();
 	shared_ptr<ZLInputStream> lock = ZLFile(path).inputStream();
 	const std::string opf = opfFileName(path);
-	bool code = OEBDescriptionReader(description).readDescription(opf);
-	if (code && description.language().empty()) {
+	bool code = OEBMetaInfoReader(book).readMetaInfo(opf);
+	if (code && book.language().empty()) {
 		shared_ptr<ZLInputStream> oebStream = new OEBTextStream(opf);
-		detectLanguage(description, *oebStream);
+		detectLanguage(book, *oebStream);
 	}
 	return code;
 }
@@ -89,12 +97,18 @@ private:
 InputStreamLock::InputStreamLock(shared_ptr<ZLInputStream> stream) : myStream(stream) {
 }
 
-bool OEBPlugin::readModel(const BookDescription &description, BookModel &model) const {
+bool OEBPlugin::readModel(BookModel &model) const {
+	const std::string &filePath = model.book()->filePath();
 	model.addUserData(
 		"inputStreamLock",
-		new InputStreamLock(ZLFile(description.fileName()).inputStream())
+		new InputStreamLock(ZLFile(filePath).inputStream())
 	);
-	return OEBBookReader(model).readBook(opfFileName(description.fileName()));
+	return OEBBookReader(model).readBook(opfFileName(filePath));
+}
+
+shared_ptr<ZLImage> OEBPlugin::coverImage(const Book &book) const {
+	const std::string opf = opfFileName(book.filePath());
+	return OEBCoverReader().readCover(opf);
 }
 
 const std::string &OEBPlugin::iconName() const {
