@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,26 +20,31 @@
 #ifndef __PALMDOCSTREAM_H__
 #define __PALMDOCSTREAM_H__
 
-#include "PdbStream.h"
+#include "PalmDocLikeStream.h"
 
 class ZLFile;
+class HuffDecompressor;
 
-class PalmDocStream : public PdbStream {
+class PalmDocStream : public PalmDocLikeStream {
 
 public:
 	PalmDocStream(ZLFile &file);
 	~PalmDocStream();
-	bool open();
+	
+	std::pair<int,int> imageLocation(const PdbHeader &header, int index) const;
+	bool hasExtraSections() const;
+	int firstImageLocationIndex(const std::string &fileName);
 
-protected:
-	bool fillBuffer();
+private:
+	bool processRecord();
+	bool processZeroRecord();
 
-protected:
-	bool myIsCompressed;
+private:
+	unsigned short myCompressionVersion;
+	unsigned long  myTextLength; //TODO: Warning: isn't used
+	unsigned short myTextRecordNumber;
 
-	size_t myMaxRecordIndex;
-	unsigned short myMaxRecordSize;
-	size_t myRecordIndex;
+	shared_ptr<HuffDecompressor> myHuffDecompressorPtr;
 };
 
 #endif /* __PALMDOCSTREAM_H__ */
