@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,9 @@
 
 #include "PdfDescriptionReader.h"
 
-PdfDescriptionReader::PdfDescriptionReader(BookDescription &description) : myDescription(description) {
+PdfDescriptionReader::PdfDescriptionReader(Book &book) : myBook(book) {
 }
 
-bool PdfDescriptionReader::readDescription(shared_ptr<ZLInputStream> stream) {
+bool PdfDescriptionReader::readMetaInfo(shared_ptr<ZLInputStream> stream) {
 	return true;
 }
