@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,17 +22,17 @@
 
 #include <string>
 
-#include "../../description/BookDescription.h"
+class Book;
 
 class PdfDescriptionReader {
 
 public:
-	PdfDescriptionReader(BookDescription &description);
+	PdfDescriptionReader(Book &book);
 	~PdfDescriptionReader();
-	bool readDescription(shared_ptr<ZLInputStream> stream);
+	bool readMetaInfo(shared_ptr<ZLInputStream> stream);
 
 private:
-	WritableBookDescription myDescription;
+	Book &myBook;
 };
 
 inline PdfDescriptionReader::~PdfDescriptionReader() {}
