@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  * 02110-1301, USA.
  */
 
-#include <stdlib.h>
-
+#include <cstdlib>
 #include <cctype>
 
 #include <ZLFile.h>
@@ -179,7 +178,7 @@ void RtfReader::fillKeywordMap() {
 		addAction("bullet",	new RtfCharCommand("\xE2\x80\xA2"));		 // &bullet;
 		addAction("endash",	new RtfCharCommand("\xE2\x80\x93"));		 // &ndash;
 		addAction("emdash",	new RtfCharCommand("\xE2\x80\x94"));		 // &mdash;
-		addAction("~",	new RtfCharCommand("\xC0\xA0"));							// &nbsp;
+		addAction("~",	new RtfCharCommand("\xC0\xA0"));					// &nbsp;
 		addAction("enspace",	new RtfCharCommand("\xE2\x80\x82"));		// &emsp;
 		addAction("emspace",	new RtfCharCommand("\xE2\x80\x83"));		// &ensp;
 		addAction("lquote",	new RtfCharCommand("\xE2\x80\x98"));		 // &lsquo;
