@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 class EntityFilesCollector {
 
 public:
-	static EntityFilesCollector &instance();
+	static EntityFilesCollector &Instance();
 
 	const std::vector<std::string> &externalDTDs(const std::string &format);
 
