@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #define __HTMLDCTAGSREADER_H__
 
 #include "../formats/html/HtmlReader.h"
-#include "../description/BookDescription.h"
+#include "BookInfo.h"
 
 class HtmlDCTagsReader : public HtmlReader {
 
