@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * 02110-1301, USA.
  */
 
-#include "../options/FBOptions.h"
+#include "../options/FBCategoryKey.h"
 
 #include "Migration.h"
 #include "migrate.h"
@@ -37,6 +37,7 @@ void MigrationRunnable::run() {
 	Migration_0_8_13().doMigration();
 	Migration_0_8_16().doMigration();
 	Migration_0_10_4().doMigration();
+	Migration_0_11_0().doMigration();
 
 	myVersionOption.setValue(VERSION);
 }
