@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,7 +41,8 @@ void TimeoutEntry::onAccept(int value) {
 	ZLSimpleSpinOptionEntry::onAccept(value);
 }
 
-ConfigPage::ConfigPage(FBReader &fbreader, ZLDialogContent &dialogTab) {
+ConfigPage::ConfigPage(ZLDialogContent &dialogTab) {
+	FBReader &fbreader = FBReader::Instance();
 	ZLToggleBooleanOptionEntry *enableEntry =
 		new ZLToggleBooleanOptionEntry(fbreader.ConfigAutoSavingOption);
 	dialogTab.addOption(ZLResourceKey("autoSave"), enableEntry);
