@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,13 +20,12 @@
 #ifndef __CONFIGPAGE_H__
 #define __CONFIGPAGE_H__
 
-class FBReader;
 class ZLDialogContent;
 
 class ConfigPage {
 
 public:
-	ConfigPage(FBReader &fbreader, ZLDialogContent &dialogTab);
+	ConfigPage(ZLDialogContent &dialogTab);
 };
 
 #endif /* __CONFIGPAGE_H__ */
