@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -122,7 +122,7 @@ void IndicatorTypeEntry::onValueSelected(int index) {
 	}
 }
 
-void OptionsDialog::createIndicatorTab(FBReader &fbreader) {
+void OptionsDialog::createIndicatorTab() {
 	ZLDialogContent &indicatorTab = myDialog->createTab(ZLResourceKey("Indicator"));
 	FBIndicatorStyle &indicatorInfo = FBView::commonIndicatorInfo();
 	static ZLResourceKey typeKey("type");
@@ -156,7 +156,7 @@ void OptionsDialog::createIndicatorTab(FBReader &fbreader) {
 	showTimeEntry->addDependentEntry(fontSizeEntry);
 
 	ZLOptionEntry *tocMarksEntry =
-		new ZLSimpleBooleanOptionEntry(fbreader.bookTextView().ShowTOCMarksOption);
+		new ZLSimpleBooleanOptionEntry(FBReader::Instance().bookTextView().ShowTOCMarksOption);
 	indicatorTab.addOption(ZLResourceKey("tocMarks"), tocMarksEntry);
 	indicatorTypeEntry->addDependentEntry(tocMarksEntry);
 
