@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,13 +22,12 @@
 
 #include <ZLOptionEntry.h>
 
-class FBReader;
 class ZLDialogContent;
 
 class KeyBindingsPage {
 
 public:
-	KeyBindingsPage(FBReader &fbreader, ZLDialogContent &dialogTab);
+	KeyBindingsPage(ZLDialogContent &dialogTab);
 };
 
 #endif /* __KEYBINDINGSPAGE_H__ */
