@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,10 +24,12 @@
 
 #include <ZLTextView.h>
 #include <ZLTextStyle.h>
+#include <ZLTextStyleCollection.h>
 #include <ZLTextStyleOptions.h>
 
 #include "StyleOptionsPage.h"
 
+#include "../options/FBTextStyle.h"
 #include "../bookmodel/FBTextKind.h"
 
 static const ZLResourceKey KEY_STYLE("style");
@@ -48,7 +50,7 @@ StyleOptionsPage::StyleOptionsPage(ZLDialogContent &dialogTab, ZLPaintContext &c
 	myComboEntry = new ComboOptionEntry(*this, styleResource[KEY_BASE].value());
 	myComboEntry->addValue(myComboEntry->initialValue());
 
-	ZLTextStyleCollection &collection = ZLTextStyleCollection::instance();
+	ZLTextStyleCollection &collection = ZLTextStyleCollection::Instance();
 	ZLTextKind styles[] = { REGULAR, TITLE, SECTION_TITLE, SUBTITLE, H1, H2, H3, H4, H5, H6, CONTENTS_TABLE_ENTRY, LIBRARY_ENTRY, ANNOTATION, EPIGRAPH, AUTHOR, DATEKIND, POEM_TITLE, STANZA, VERSE, CITE, INTERNAL_HYPERLINK, EXTERNAL_HYPERLINK, BOOK_HYPERLINK, FOOTNOTE, ITALIC, EMPHASIS, BOLD, STRONG, DEFINITION, DEFINITION_DESCRIPTION, PREFORMATTED, CODE };
 	const int STYLES_NUMBER = sizeof(styles) / sizeof(ZLTextKind);
 	for (int i = 0; i < STYLES_NUMBER; ++i) {
@@ -61,7 +63,7 @@ StyleOptionsPage::StyleOptionsPage(ZLDialogContent &dialogTab, ZLPaintContext &c
 
 	{
 		const std::string &name = myComboEntry->initialValue();
-		ZLTextBaseStyle &baseStyle = collection.baseStyle();
+		FBTextStyle &baseStyle = FBTextStyle::Instance();
 
 		registerEntry(dialogTab,
 			KEY_FONTFAMILY, new ZLFontFamilyOptionEntry(baseStyle.FontFamilyOption, context),
@@ -84,7 +86,7 @@ StyleOptionsPage::StyleOptionsPage(ZLDialogContent &dialogTab, ZLPaintContext &c
 		);
 
 		registerEntry(dialogTab,
-			KEY_AUTOHYPHENATIONS, new ZLSimpleBooleanOptionEntry(baseStyle.AutoHyphenationOption),
+			KEY_AUTOHYPHENATIONS, new ZLSimpleBooleanOptionEntry(collection.AutoHyphenationOption),
 			name
 		);
 	}
